[![Build Status](https://travis-ci.com/yandexdataschool/QuantileTransformerTF.svg?branch=master)](https://travis-ci.com/yandexdataschool/QuantileTransformerTF) [![DOI](https://zenodo.org/badge/156366202.svg)](https://zenodo.org/badge/latestdoi/156366202)

# QuantileTransformerTF
Tensorflow implementation of `sklearn.preprocessing.QuantileTransformer`. Transform only - please use the sklearn to fit.

## Installation

The releases are published on PyPi
```
pip install quantile_transformer_tf
```
To install from the source
```
python setup.py install
```

## Usage
Please see the docstrings and `test.py`

Please cite as [![DOI](https://zenodo.org/badge/156366202.svg)](https://zenodo.org/badge/latestdoi/156366202)
